@@ -105,31 +105,13 @@
 #' @export
 #' @rdname diff_vec
 diff_vec <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL, silent = FALSE) {
+
     # Checks
+    if (!is.numeric(x)) rlang::abort("Non-numeric data detected. 'x' must be numeric.")
     if (length(lag) > 1) rlang::abort("length(lag) > 1): Multiple lags detected. Use tk_augment_diff().")
     if (length(difference) > 1) rlang::abort("diff_vec(length(difference) > 1): Multiple differences detected. Use tk_augment_diff().")
     if (!is.null(initial_values)) rlang::warn("`initial_values` are not required for the `diff_vec()` calculation.")
 
-    UseMethod("diff_vec", x)
-}
-
-#' @export
-diff_vec.default <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL, silent = FALSE) {
-    rlang::abort(paste0("diff_vec: No method for class ", class(x)[[1]], "."))
-}
-
-#' @export
-diff_vec.double <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL, silent = FALSE) {
-    diff_calc(x, lag, difference, log, silent)
-}
-
-#' @export
-diff_vec.integer <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL, silent = FALSE) {
-    diff_calc(x, lag, difference, log, silent)
-}
-
-diff_calc <- function(x, lag, difference, log, silent = FALSE) {
-
     if (!silent) message("diff_vec(): Initial values: ",
                          stringr::str_c(x[1:(lag * difference)], collapse = ", "))
 
@@ -156,6 +138,7 @@ diff_calc <- function(x, lag, difference, log, silent = FALSE) {
 #' @export
 diff_inv_vec <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL) {
     # Checks
+    if (!is.numeric(x)) rlang::abort("Non-numeric data detected. 'x' must be numeric.")
     if (length(lag) > 1) stop(call. = FALSE, "diff_inv_vec(length(lag) > 1): Multiple lags detected. Use tk_augment_diff().")
     if (length(difference) > 1) stop(call. = FALSE, "diff_inv_vec(length(difference) > 1): Multiple differences detected. Use tk_augment_diff().")
 
@@ -164,25 +147,6 @@ diff_inv_vec <- function(x, lag = 1, difference = 1, log = FALSE, initial_values
             stop(call. = FALSE, "diff_inv_vec(initial_values): Size of lag values must match the number of missing values generated by the differencing operation.")
         }
     }
-    UseMethod("diff_inv_vec", x)
-}
-
-#' @export
-diff_inv_vec.default <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL) {
-    stop(paste0("diff_inv_vec: No method for class ", class(x)[[1]], "."), call. = FALSE)
-}
-
-#' @export
-diff_inv_vec.double <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL) {
-    diff_inv_calc(x, lag, difference, log, initial_values)
-}
-
-#' @export
-diff_inv_vec.integer <- function(x, lag = 1, difference = 1, log = FALSE, initial_values = NULL) {
-    diff_inv_calc(x, lag, difference, log, initial_values)
-}
-
-diff_inv_calc <- function(x, lag, difference, log, initial_values = NULL) {
 
     na_len <- is.na(x) %>% sum()
     x_trim <- x[!is.na(x)]
