@@ -1,19 +1,24 @@
-library(testthat)
-library(timetk)
-library(dplyr)
-library(tidyr)
-library(ggplot2)
-library(stringr)
-library(lubridate)
-library(zoo)
-
 # Forecast objects
 library(forecast)
 library(fracdiff)
 library(timeDate)
 library(tseries)
+library(timeSeries)
 
 # Feature engineering
 library(recipes)
 
+# Time Series
+library(lubridate)
+library(zoo)
+library(timetk)
+
+# Other
+library(stringr)
+library(dplyr)
+library(tidyr)
+library(ggplot2)
+
+library(testthat)
+
 test_check("timetk")
